%% Script to run for all type of analyses

global cLum h hbar kB au a0
global mSr a8484 aScat lambda gamma clebsch detuning absCross tof
global hbarOverAu auOverkB

close all

%parpool  % to be used with newer version of MATLAB (2019), in order to use the parallel calculation option of lsqcurvefit. Does not exist on MATLAB 2015


%% Definition of useful constants and physical quantities

cLum=2.99792458e8; % m/s ; exactly defined
h=6.62607015e-34; % J.s ; exactly defined
hbar = h/(2*pi);
kB = 1.380649e-23; %J/K ; exactly defined
au = 1.66053906660e-27; % kg
a0 = 0.0529177210903e-9; % Bohr radius, in m
hbarOverAu = hbar/au;
auOverkB = au / kB;


m84Sr =  83.913425; % au
m86Sr =  85.9092607309; % au
m87Sr =  86.9088774970; % au
m88Sr =  87.9056122571; % au
mSr = m84Sr; % au
% a8686 = 823 * a0;
a8484 = 122.7*a0; % m
aScat = a8484; % m
lambda=460.862369e-9; % m
gamma=2*pi*30.2e6; % s^-1
detuning=2*pi * 0;
clebsch=1;
absCross=clebsch*3*lambda^2/(2*pi*(1+(detuning/(2*gamma))^2)); % m^2
tof=18e-3; % time of flight, in s


%%
params=visionplotparams;
params.RunningFolder = mfilename('fullpath'); 
params.filename = mfilename();
filename = saveScript(params.RunningFolder,params.filename);
params.displayimageloadingmessages=1;
params.title=[filename,'PCA'];

params.xlabel='Runing Time [ms]';
params.ylabel='PCA Mode';

% params.title='Flux Measurement';
% params.xoffset=[0, 0, 0, -10000, -20000, -3000];
% params.yoffset=[0:3e6:2*3e6];
% params.yoffsld inteet=([0.223,0.215,0.638]-0.223)*1e6; % 0:1e5:2e5;
% % params.xoffset=0;
% % % params.xoffset=80.5;
% % % params.xoffset=80-0.25;
%  params.yscale=[1/(2.4*10^3),1/(2.4*10^3),1/(2.4*10^3),1/(2.4*10^3),1/(2.4*10^3),1/(2.4*10^3),1/(2.9*10^4)];
% params.xscale=689e-9*1e6;7
% params.legendtext={'160518S301: 83.6/83.8, 1MHZ','160519S5: 83.6/83.8, 2MHZ','160519S6: 83.6/83.8, 3MHZ','160518S22: 83.6/83.8, 2MHZ','160519S7: 83.6/83.8, 5MHZ','160518S26: 83.6/83.8, 6MHZ'};
% params.legendtext={'160522S53: ALVH 3A Flipped ALZAH 3.75A, ALZH 5.5A, Z 80.4:81','160522S53: ALVH 3A Flipped ALZAH 3.75A, ALZH 5.5A, Z 80.4:81','160522S52: ALVH 2.5A Flipped ALZAH 3.75A, ALZH 5.5A, Z 80.4:81','160522S51: ALVH 2A Flipped ALZAH 3.75A, ALZH 5.5A, Z 80.4:81','160522S50: ALVH 1.5A Flipped ALZAH 3.75A, ALZH 5.5A, Z 80.4:81','160522S49: ALVH 1A Flipped ALZAH 3.75A, ALZH 5.5A, Z 80.4:81','160522S48: ALVH 0.5A Flipped ALZAH 3.75A, ALZH 5.5A, Z 80.4:81','160522S42: ALVH 0A ALZAH 3.75A, ALZH 5.5A, Z 80.4:81','160522S41: ALVH 0.5A ALZAH 3.75A, ALZH 5.5A, Z 80.4:81','160522S40: ALVH 1A ALZAH 3.75A, ALZH 5.5A, Z 80.4:81','160522S37: ALVH 1.5A ALZAH 3.75A, ALZH 5.5A, Z 80.4:81','160522S39: ALVH 2A ALZAH 3.75A, ALZH 5.5A, Z 80.4:81','160522S46: ALVH 2.5A ALZAH 3.75A, ALZH 5.5A, Z 80.4:81','160522S47: ALVH 3A ALZAH 3.75A, ALZH 5.5A, Z 80.4:81'};
% 
% params.displayseriesparameters=1;


%% Plot style

% params.legendtext={'160522S42: ALVH 0A ALZAH 3.75A, ALZH 5.5A, Z 80.4:81','160524S43: ALVH 0A ALZAH 3.75A, ALZH 5.0A, Z 80.4:81','160524S42: ALVH 0A ALZAH 3.75A, ALZH 5.5A, Z 80.4:81','160524S44: ALVH 0A ALZAH 3.75A, ALZH 6.0A, Z 80.4:81','160524S45: ALVH 0A ALZAH 3.75A, ALZH 6.5A, Z 80.4:81','160524S46: ALVH 0A ALZAH 3.75A, ALZH 6.3A, Z 80.4:81','160525S17: ALVH 0A ALZAH 3.75A, ALZH 5.5A, RTHH: 0A, Z 80.4:81','160525S18: ALVH 0A ALZAH 3.75A, ALZH 5.5A, RTHH: 0.2A, Z 80.4:81'};
params.linestyle='.';
params.plotoptions='''LineWidth'',10';
% params.linecolour={'k','r','m'};
% params.plotoptions='''MarkerSize'',20,''LineWidth'',5';
% params.linestyle='-';25


%% Axes labeling ;

% params.xlabel='SOLD intensity [%]';
% params.title='Velocity distribution based on non magnetic transition';


%% Data informations ;

seriesvals=20;
dateval='191227';


%% Camera # / scanned variables

params.cameranumber=1;
params.dataparameters=1;
params.legendstext = {'Run series'};
params.dofit=4; % fit 4, exponential loading


params.analysis = 23; % Put 23 for fitting of both thermal and BEC
params.reloadimages=false; % force reload images, even if the .mat file already exist
params.reloadfitting=false; % force recalculate fit, even if the .dat file already exists


params.legendlocation='southoutside';
% params.removenegative=1;
params.linestyle='.';
params.datasection=params.dataparameters+11;
% params.xlabel='Wait [ms]';
params.ylabel='NI';
params.PCAmodeNumber=1:2;
params.blursize=0;
verticalOffset=83; %put to 0 for fast fit, put to 83 for powerpoint slides
verticalSizeIncrease=2*verticalOffset;
params.PCAcrop=round([504 11 235 985]);
params.Plotcrop=round([504-verticalOffset   11  235+verticalSizeIncrease  985]);
params.doProbeIntensityCompensation=true;
params.ProbeIntensityCompensationRegion=[1 450 800 1000]; 
params.CrosssectionHalfWidth=20;
params.resultsname=datestr(now,'yyyymmddHHMMSS'); % the directory name for the results


%% Th+BEC fit specific parameters

params.SSBECfitparam.dimpleXrange=[429 531];
params.SSBECfitparam.reservoirXrange1=[320 370];  
params.SSBECfitparam.reservoirXrange2=[570 836];
params.SSBECfitparam.transportXrange1=[11 259];  
params.SSBECfitparam.transportXrange2=[867 968];
params.SSBECfitparam.aperturex=[465 490]; 
params.SSBECfitparam.aperturey=[608 658];
params.SSBECfitparam.Xcal=4.48036*1e-3;
params.SSBECfitparam.Ycal=4.48036*1e-3;
params.SSBECfitparam.border=50;
params.SSBECfitparam.borderedge=10;
params.SSBECfitparam.plotseedingfits=0;
params.SSBECfitparam.showaperture=0;
params.SSBECfitparam.fittolerance=1e-4;
params.SSBECfitparam.maxiterations=2000;
params.SSBECfitparam.showinterationplots=50;
params.SSBECfitparam.MINBECSIZE=500;
params.SSBECfitparam.fitType=1; % 0=fminsearch / else=lsqcurvefit
params.SSBECfitparam.fixedBECtrapfrequency=1; % 0= not fixed / 1= fixed by x0
params.SSBECfitparam.fixedBECWx=2*pi*315; % x0(20)=BECWx when fixed
params.SSBECfitparam.fixedBECWy=2*pi*555; % x0(21)=BECWy when fixed
params.SSBECfitparam.tof=18e-3; % in s



%% Th+BEC fit constraints

params.fittype.limits(1,1:2)=[0.001 150];                                  % Parameters(1)=DimpleN;
params.fittype.limits(2,1:2)=[0.2 0.5];                                    % Parameters(2)=DimpleWy;
params.fittype.limits(3,1:2)=[0.001 60];                                   % Parameters(3)=ReservoirN;
params.fittype.limits(4,1:2)=[0.1 0.5];                                    % Parameters(4)=ReservoirWy;
params.fittype.limits(5,1:2)=[0.4 2];                                      % Parameters(5)=ReservoirWx;
params.fittype.limits(6,1:2)=[0.001 100];                                  % Parameters(6)=CrossoverN;
params.fittype.limits(7,1:2)=[0.1 0.4];                                    % Parameters(7)=CrossoverWy;
params.fittype.limits(8,1:2)=[0.1 0.7];                                    % Parameters(8)=CrossoverWx;
params.fittype.limits(9,1:2)=params.SSBECfitparam.aperturex*params.SSBECfitparam.Xcal;   % Parameters(9)=Dimplex;
params.fittype.limits(10,1:2)=params.SSBECfitparam.aperturey*params.SSBECfitparam.Ycal;  % Parameters(10)=Dimpley;
params.fittype.limits(11,1:2)=[params.SSBECfitparam.reservoirXrange1(1) params.SSBECfitparam.reservoirXrange2(2)]*params.SSBECfitparam.Xcal;      % Parameters(11)=Crossoverx;
%params.fittype.limits(12,1:2)=[params.SSBECfitparam.reservoirXrange1(1) params.SSBECfitparam.reservoirXrange2(2)]*params.SSBECfitparam.Xcal;      % Parameters(12)=Reservoirx;
params.fittype.limits(12,1:2)=[1.5 2.55];                                  % Parameters(12)=Reservoirx;
params.fittype.limits(13,1:2)=[0.001 15];                                  % Parameters(13)=transportN;
%fittype.limits(14,1:2)=[SSBECfitparam.reservoirXrange1(1) SSBECfitparam.transportXrange2(2)]*SSBECfitparam.Xcal;      % Parameters(14)=transportX;
params.fittype.limits(14,1:2)=[3.55 4.5];                                  % Parameters(14)=transportX;
params.fittype.limits(15,1:2)=[0.01 2];                                    % Parameters(15)=transportWx;
params.fittype.limits(16,1:2)=[0.95*params.SSBECfitparam.aperturey(1) params.SSBECfitparam.aperturey(2)]*params.SSBECfitparam.Ycal;  % Parameters(16)=transportY;
params.fittype.limits(17,1:2)=[0.05 0.4];                                  % Parameters(17)=transportWy;
params.fittype.limits(18,1:2)=[-1 1];                                      % Parameters(18)=Background;
params.fittype.limits(19,1:2)=[0 4e4];                                     % Parameters(19)=BECN;
params.fittype.limits(20,1:2)=[2*pi*200 2*pi*600];                         % Parameters(20)=BECwx;
params.fittype.limits(21,1:2)=[2*pi*400 2*pi*1150];                        % Parameters(21)=BECwy;
params.fittype.limits(22,1:2)=params.SSBECfitparam.aperturex*params.SSBECfitparam.Xcal;  % Parameters(22)=BECX;
params.fittype.limits(23,1:2)=params.SSBECfitparam.aperturey*params.SSBECfitparam.Ycal;  % Parameters(23)=BECY;


%% parameters to produce nice color scale

% params.datacolormapfilename='jet';
% params.fitcolormapfilename='jet';
% params.thermalcolormapfilename='jet';
% params.residualcolormapfilename='jet';

params.datacolormapfilename='Q:\qgases\groups\strontium\SrCAL\Data\SSBEC\Analysis\191226\S18Fits\ColorScalessBEC18msTOFV2.dat';
params.fitcolormapfilename='Q:\qgases\groups\strontium\SrCAL\Data\SSBEC\Analysis\191226\S18Fits\ColorScalessBEC18msTOFV2.dat';
params.thermalcolormapfilename='Q:\qgases\groups\strontium\SrCAL\Data\SSBEC\Analysis\191226\S18Fits\ColorScalessBEC18msTOFV2.dat';
params.residualcolormapfilename='Q:\qgases\groups\strontium\SrCAL\Data\SSBEC\Analysis\191226\S18Fits\ColorScalessBEC18msTOFV2Residuals.dat';


%% call the load+fit+analyze function

plotvisionseriesv7(seriesvals,dateval,params);


