
% Load of results from the fitting program

directory = 'Q:\qgases\groups\strontium\SrCAL\Data\SSBEC\191226\S18\Results20200218203040\';
if ~exist('PCAmatrix','var')
    load('Q:\qgases\groups\strontium\SrCAL\Data\SSBEC\191226\S18\Results20200218203040\fitdataset.mat');
    load('Q:\qgases\groups\strontium\SrCAL\Data\SSBEC\191226\S18\imagedataset.mat');
end

global cLum h hbar kB au a0
global mSr a8484 aScat lambda gamma clebsch detuning absCross tof
global hbarOverAu auOverkB

% Definition of useful constants and physical quantities

cLum=2.99792458e8; % m/s ; exactly defined
h=6.62607015e-34; % J.s ; exactly defined
hbar = h/(2*pi);
kB = 1.380649e-23; %J/K ; exactly defined
au = 1.66053906660e-27; % kg
a0 = 0.0529177210903e-9; % Bohr radius, in m
hbarOverAu = hbar/au;
auOverkB = au / kB;

m84Sr =  83.913425; % au
m86Sr =  85.9092607309; % au
m87Sr =  86.9088774970; % au
m88Sr =  87.9056122571; % au
mSr = m84Sr; % au
% a8686 = 823 * a0;
a8484 = 122.7*a0; % m
aScat = a8484; % m
lambda=460.862369e-9; % m
gamma=2*pi*30.2e6; % s^-1
detuning=2*pi * 0;
clebsch=1;
absCross=clebsch*3*lambda^2/(2*pi*(1+(detuning/(2*gamma))^2)); % m^2
tof=18e-3; % time of flight, in s
atomVelocity = 0.088; % in m.s^-1 , velocity of atoms in the transport guide
sigmaAtomVelocity = 0.008;
                    

% Load custom color maps

datacolormapfilename='Q:\qgases\groups\strontium\SrCAL\Data\SSBEC\Analysis\191226\S18Fits\ColorScalessBEC18msTOFV2.dat';
fitcolormapfilename='Q:\qgases\groups\strontium\SrCAL\Data\SSBEC\Analysis\191226\S18Fits\ColorScalessBEC18msTOFV2.dat';
thermalcolormapfilename='Q:\qgases\groups\strontium\SrCAL\Data\SSBEC\Analysis\191226\S18Fits\ColorScalessBEC18msTOFV2.dat';
residualcolormapfilename='Q:\qgases\groups\strontium\SrCAL\Data\SSBEC\Analysis\191226\S18Fits\ColorScalessBEC18msTOFV2Residuals.dat';
[datamap]=readcolormap(datacolormapfilename);
[fitmap]=readcolormap(fitcolormapfilename);
[thermalmap]=readcolormap(thermalcolormapfilename);
[residualmap]=readcolormap(residualcolormapfilename);

% cycle over data

timesofinterest=unique(xdatagood);
% timesofinterest=2600;

sizMat = size(PCAmatrix);

for timeset=1:length(timesofinterest)
    thistimeval=timesofinterest(timeset),
    piclist=find(xdatagood==thistimeval)+1;
    for picnum=piclist
        header1=['Paper-SingleShot-'];
        header2=['-',num2str(thistimeval),'ms-im',num2str(picnum)];

        % Prepare the data for analysis

%         nbTotPic = sizMat(1)-1;
%         meanImDataTab = repmat(PCAmatrix(1,:),nbTotPic,1);
        nbTotPic=1;
        meanImDataTab = PCAmatrix(picnum,:);

        PCAcrop = roilocation;
        X=((1:size(imdata,2))+PCAcrop(2)-1)*SSBECfitparam.Xcal;
        Y=((1:size(imdata,1))+PCAcrop(1)-1)*SSBECfitparam.Ycal;
        [xx,yy]=meshgrid(X,Y);
        [dimX,dimY] = size(xx);

        meanImData = reshape(meanImDataTab(1,:),[dimX dimY]);


        % Create 2D image and fit 

        x0Thseries = (1:23)*0;
%         x0Thseries(1:18) = x0FirstFitseries(1,1:18);
        x0Thseries(1:18) = x0FirstFitseries(picnum,1:18);

%         [fittedData,dimplefit,reservoirfit,crossoverfit,transportfit,BECfit] = constructSSBEC6(x0series(1,:),xx,yy);
        [fittedData,dimplefit,reservoirfit,crossoverfit,transportfit,BECfit] = constructSSBEC6(x0series(picnum,:),xx,yy);
        [fittedThData,dimpleThfit,reservoirThfit,crossoverThfit,transportThfit,BECThfit] = constructSSBEC6(x0Thseries,xx,yy);

        fitsummaryfig1 = 1;
        fitsummaryfig2 = 2;
        fitsummaryfig3 = 3;
        fitsummaryfig4 = 4; 
        fitsummaryfig5 = 5; 
        fitsummaryfig6 = 6; 
        fitsummaryfig7 = 7; 


        figure(fitsummaryfig1);
        subplot(3,1,1,'replace');
        imagesc(meanImData);
        fittype.climits=get(gca,'cLim');
        title('Mean picture');
        colorbar;
        subplot(3,1,2,'replace');
        imagesc(fittedData);
        fittype.climits=get(gca,'cLim');
        title('Thermal+BEC fit recreated picture');
        colorbar;
        subplot(3,1,3,'replace');
        imagesc(fittedThData);
        fittype.climits=get(gca,'cLim');
        title('Thermal fit recreated picture');
        colorbar;
        colormap(datamap);
        %colormap jet


        figure(fitsummaryfig2);
        subplot(2,1,1,'replace');
        imagesc(meanImData-fittedData);
        %fittype.climits=get(gca,'cLim');
        title('Residual thermal+BEC fit');
        colorbar;
        subplot(2,1,2,'replace');
        imagesc(meanImData-fittedThData);
        fittype.climits=get(gca,'cLim');
        title('Residual thermal fit');
        colorbar;
        colormap(residualmap);
        %colormap jet


        % Prepare cross-sections and projections

        CrosssectionHalfWidthX=20; % change to improve the contrast
        CrosssectionHalfWidthY=20; % change to improve the contrast

        Xcal=4.48036*1e-3;
        Ycal=4.48036*1e-3;
        Dimplex=round(x0series(1,9)/Xcal-PCAcrop(2)); % Parameters(10)=Dimpley;
        Dimpley=round(x0series(1,10)/Ycal-PCAcrop(1)); % Parameters(10)=Dimpley;


        datacrosssectionX =sum(meanImData((Dimpley-CrosssectionHalfWidthX):(Dimpley+CrosssectionHalfWidthX),:),1);
        thermalcrosssectionXThPlusBEC=sum(dimplefit((Dimpley-CrosssectionHalfWidthX):(Dimpley+CrosssectionHalfWidthX),:)+...
            reservoirfit((Dimpley-CrosssectionHalfWidthX):(Dimpley+CrosssectionHalfWidthX),:)+...
            crossoverfit((Dimpley-CrosssectionHalfWidthX):(Dimpley+CrosssectionHalfWidthX),:)+...
            transportfit((Dimpley-CrosssectionHalfWidthX):(Dimpley+CrosssectionHalfWidthX),:),1);
        % dimplecrosssectionXThPlusBEC=sum(dimplefit((Dimpley-CrosssectionHalfWidthX):(Dimpley+CrosssectionHalfWidthX),:),1);
        % reservoircrosssectionXThPlusBEC=sum(reservoirfit((Dimpley-CrosssectionHalfWidthX):(Dimpley+CrosssectionHalfWidthX),:),1);
        % crossovercrosssectionXThPlusBEC=sum(crossoverfit((Dimpley-CrosssectionHalfWidthX):(Dimpley+CrosssectionHalfWidthX),:),1);
        % transportcrosssectionXThPlusBEC=sum(transportfit((Dimpley-CrosssectionHalfWidthX):(Dimpley+CrosssectionHalfWidthX),:),1);
        BECcrosssectionXThPlusBEC=sum(BECfit((Dimpley-CrosssectionHalfWidthX):(Dimpley+CrosssectionHalfWidthX),:),1);
        thermalcrosssectionXTh=sum(dimpleThfit((Dimpley-CrosssectionHalfWidthX):(Dimpley+CrosssectionHalfWidthX),:)+...
            reservoirThfit((Dimpley-CrosssectionHalfWidthX):(Dimpley+CrosssectionHalfWidthX),:)+...
            crossoverThfit((Dimpley-CrosssectionHalfWidthX):(Dimpley+CrosssectionHalfWidthX),:)+...
            transportThfit((Dimpley-CrosssectionHalfWidthX):(Dimpley+CrosssectionHalfWidthX),:),1);
        % dimplecrosssectionXTh=sum(dimpleThfit((Dimpley-CrosssectionHalfWidthX):(Dimpley+CrosssectionHalfWidthX),:),1);
        % reservoircrosssectionXTh=sum(reservoirThfit((Dimpley-CrosssectionHalfWidthX):(Dimpley+CrosssectionHalfWidthX),:),1);
        % crossovercrosssectionXTh=sum(crossoverThfit((Dimpley-CrosssectionHalfWidthX):(Dimpley+CrosssectionHalfWidthX),:),1);
        % transportcrosssectionXTh=sum(transportThfit((Dimpley-CrosssectionHalfWidthX):(Dimpley+CrosssectionHalfWidthX),:),1);

        datacrosssectionY =sum(meanImData(:,(Dimplex-CrosssectionHalfWidthY):(Dimplex+CrosssectionHalfWidthY)),2);
        thermalcrosssectionYThPlusBEC=sum(dimplefit(:,(Dimplex-CrosssectionHalfWidthY):(Dimplex+CrosssectionHalfWidthY))+...
            reservoirfit(:,(Dimplex-CrosssectionHalfWidthY):(Dimplex+CrosssectionHalfWidthY))+...
            crossoverfit(:,(Dimplex-CrosssectionHalfWidthY):(Dimplex+CrosssectionHalfWidthY))+...
            transportfit(:,(Dimplex-CrosssectionHalfWidthY):(Dimplex+CrosssectionHalfWidthY)),2);
        % dimplecrosssectionYThPlusBEC=sum(dimplefit((Dimplex-CrosssectionHalfWidthY):(Dimplex+CrosssectionHalfWidthY)),2);
        % reservoircrosssectionYThPlusBEC=sum(reservoirfit(:,(Dimplex-CrosssectionHalfWidthY):(Dimplex+CrosssectionHalfWidthY)),2);
        % crossovercrosssectionYThPlusBEC=sum(crossoverfit(:,(Dimplex-CrosssectionHalfWidthY):(Dimplex+CrosssectionHalfWidthY)),2);
        % transportcrosssectionYThPlusBEC=sum(transportfit(:,(Dimplex-CrosssectionHalfWidthY):(Dimplex+CrosssectionHalfWidthY)),2);
        BECcrosssectionYThPlusBEC=sum(BECfit(:,(Dimplex-CrosssectionHalfWidthY):(Dimplex+CrosssectionHalfWidthY)),2);
        thermalcrosssectionYTh=sum(dimpleThfit(:,(Dimplex-CrosssectionHalfWidthY):(Dimplex+CrosssectionHalfWidthY))+...
            reservoirThfit(:,(Dimplex-CrosssectionHalfWidthY):(Dimplex+CrosssectionHalfWidthY))+...
            crossoverThfit(:,(Dimplex-CrosssectionHalfWidthY):(Dimplex+CrosssectionHalfWidthY))+...
            transportThfit(:,(Dimplex-CrosssectionHalfWidthY):(Dimplex+CrosssectionHalfWidthY)),2);
        % dimplecrosssectionYTh=sum(dimpleThfit(:,(Dimplex-CrosssectionHalfWidthY):(Dimplex+CrosssectionHalfWidthY)),2);
        % reservoircrosssectionYTh=sum(reservoirThfit(:,(Dimplex-CrosssectionHalfWidthY):(Dimplex+CrosssectionHalfWidthY)),2);
        % crossovercrosssectionYTh=sum(crossoverThfit(:,(Dimplex-CrosssectionHalfWidthY):(Dimplex+CrosssectionHalfWidthY)),2);
        % transportcrosssectionYTh=sum(transportThfit(:,(Dimplex-CrosssectionHalfWidthY):(Dimplex+CrosssectionHalfWidthY)),2);


        dataprojectionX=sum(meanImData,1);
        thermalprojectionXThPlusBEC=sum(dimplefit+reservoirfit+crossoverfit+transportfit,1);
        % dimpleprojectionXThPlusBEC=sum(dimplefit,1);
        % reservoirprojectionXThPlusBEC=sum(reservoirfit,1);
        % crossoverprojectionXThPlusBEC=sum(crossoverfit,1);
        % transportprojectionXThPlusBEC=sum(transportfit,1);
        BECprojectionXThPlusBEC=sum(BECfit,1);
        thermalprojectionXTh=sum(dimpleThfit+reservoirThfit+crossoverThfit+transportThfit,1);
        % dimpleprojectionXTh=sum(dimpleThfit,1);
        % reservoirprojectionXTh=sum(reservoirThfit,1);
        % crossoverprojectionXTh=sum(crossoverThfit,1);
        % transportprojectionXTh=sum(transportThfit,1);

        dataprojectionY=sum(meanImData,2);
        thermalprojectionYThPlusBEC=sum(dimplefit+reservoirfit+crossoverfit+transportfit,2);
        % dimpleprojectionYThPlusBEC=sum(dimplefit,2);
        % reservoirprojectionYThPlusBEC=sum(reservoirfit,2);
        % crossoverprojectionYThPlusBEC=sum(crossoverfit,2);
        % transportprojectionYThPlusBEC=sum(transportfit,2);
        BECprojectionYThPlusBEC=sum(BECfit,2);
        thermalprojectionYTh=sum(dimpleThfit+reservoirThfit+crossoverThfit+transportThfit,2);
        % dimpleprojectionYTh=sum(dimpleThfit,2);
        % reservoirprojectionYTh=sum(reservoirThfit,2);
        % crossoverprojectionYTh=sum(crossoverThfit,2);
        % transportprojectionYTh=sum(transportThfit,2);


        % Plot cross-sections and projections

        figure(fitsummaryfig3);
        subplot(2,2,1,'replace');
        %subplot('position',[0.1 0.7 PCAcrop(4)/(PCAcrop(4)+PCAcrop(3))/1.5 PCAcrop(3)/(PCAcrop(4)+PCAcrop(3))/1.5]);
        imagesc(X,Y,meanImData);
        set(gca,'YDir','normal');
        colormap(datamap);
        subplot(2,2,2,'replace');
        %subplot('position',[0.8 0.7 PCAcrop(4)/(PCAcrop(4)+PCAcrop(3))/8 PCAcrop(3)/(PCAcrop(4)+PCAcrop(3))/1.5]);
        plot(datacrosssectionY,Y,'k.',thermalcrosssectionYTh,Y,'g',BECcrosssectionYThPlusBEC+thermalcrosssectionYThPlusBEC,Y,'b',thermalcrosssectionYThPlusBEC,Y,'r');
        axis([min(thermalcrosssectionYTh) max(BECcrosssectionYThPlusBEC+thermalcrosssectionYThPlusBEC)*1.05 Y(1) Y(end)]);
        ylabel('Position after 18ms TOF [mm]');
        xlabel('Atoms cross-section');
        title('Cross-section');
        legend('Data','Thermal only fit','Thermal+BEC fit','Thermal+BEC fit minus BEC')
        subplot(2,2,3,'replace');
        %subplot('position',[0.1 0.3 PCAcrop(4)/(PCAcrop(4)+PCAcrop(3))/1.5 PCAcrop(3)/(PCAcrop(4)+PCAcrop(3))/1.5]);
        plot(X,datacrosssectionX,'k.',X,thermalcrosssectionXTh,'g',X,BECcrosssectionXThPlusBEC+thermalcrosssectionXThPlusBEC,'b',X,thermalcrosssectionXThPlusBEC,'r');
        axis([X(1) X(end) min(thermalcrosssectionXTh) max(BECcrosssectionXThPlusBEC+thermalcrosssectionXThPlusBEC)*1.05]);
        ylabel('Atoms cross-section');
        xlabel('Position after 18ms TOF [mm]');
        title('Cross-section');
        legend('Data','Thermal only fit','Thermal+BEC fit','Thermal+BEC fit minus BEC')


        figure(fitsummaryfig4);
        subplot(2,2,1,'replace');
        imagesc(X,Y,meanImData);
        set(gca,'YDir','normal');
        colormap(datamap);
        subplot(2,2,2,'replace');
        plot(dataprojectionY,Y,'k.',thermalprojectionYTh,Y,'g',thermalprojectionYThPlusBEC+BECprojectionYThPlusBEC,Y,'b',thermalprojectionYThPlusBEC,Y,'r');
        axis([min(thermalprojectionYTh) max(BECprojectionYThPlusBEC+thermalprojectionYThPlusBEC)*1.05 Y(1) Y(end)]);
        ylabel('Position after 18ms TOF [mm]');
        xlabel('Atoms projection');
        title('Projection');
        legend('Data','Thermal only fit','Thermal+BEC fit','Thermal+BEC fit minus BEC')
        subplot(2,2,3,'replace');
        plot(X,dataprojectionX,'k.',X,thermalprojectionXTh,'g',X,thermalprojectionXThPlusBEC+BECprojectionXThPlusBEC,'b',X,thermalprojectionXThPlusBEC,'r');
        axis([X(1) X(end) min(thermalprojectionXTh) max(BECprojectionXThPlusBEC+thermalprojectionXThPlusBEC)*1.05]);
        ylabel('Atoms projection');
        xlabel('Position after 18ms TOF [mm]');
        title('Projection');
        legend('Data','Thermal only fit','Thermal+BEC fit','Thermal+BEC fit minus BEC')





        % Prepare cross-sectionsV2

        CrosssectionHalfWidthX=3; % change to improve the contrast
        CrosssectionHalfWidthY=3; % change to improve the contrast

        Xcal=4.48036*1e-3;
        Ycal=4.48036*1e-3;
        Dimplex=round(x0series(1,9)/Xcal-PCAcrop(2)); % Parameters(10)=Dimpley;
        Dimpley=round(x0series(1,10)/Ycal-PCAcrop(1)); % Parameters(10)=Dimpley;


        datacrosssectionX =sum(meanImData((Dimpley-CrosssectionHalfWidthX):(Dimpley+CrosssectionHalfWidthX),:),1);
        thermalcrosssectionXThPlusBEC=sum(dimplefit((Dimpley-CrosssectionHalfWidthX):(Dimpley+CrosssectionHalfWidthX),:)+...
            reservoirfit((Dimpley-CrosssectionHalfWidthX):(Dimpley+CrosssectionHalfWidthX),:)+...
            crossoverfit((Dimpley-CrosssectionHalfWidthX):(Dimpley+CrosssectionHalfWidthX),:)+...
            transportfit((Dimpley-CrosssectionHalfWidthX):(Dimpley+CrosssectionHalfWidthX),:),1);
        % dimplecrosssectionXThPlusBEC=sum(dimplefit((Dimpley-CrosssectionHalfWidthX):(Dimpley+CrosssectionHalfWidthX),:),1);
        % reservoircrosssectionXThPlusBEC=sum(reservoirfit((Dimpley-CrosssectionHalfWidthX):(Dimpley+CrosssectionHalfWidthX),:),1);
        % crossovercrosssectionXThPlusBEC=sum(crossoverfit((Dimpley-CrosssectionHalfWidthX):(Dimpley+CrosssectionHalfWidthX),:),1);
        % transportcrosssectionXThPlusBEC=sum(transportfit((Dimpley-CrosssectionHalfWidthX):(Dimpley+CrosssectionHalfWidthX),:),1);
        BECcrosssectionXThPlusBEC=sum(BECfit((Dimpley-CrosssectionHalfWidthX):(Dimpley+CrosssectionHalfWidthX),:),1);
        thermalcrosssectionXTh=sum(dimpleThfit((Dimpley-CrosssectionHalfWidthX):(Dimpley+CrosssectionHalfWidthX),:)+...
            reservoirThfit((Dimpley-CrosssectionHalfWidthX):(Dimpley+CrosssectionHalfWidthX),:)+...
            crossoverThfit((Dimpley-CrosssectionHalfWidthX):(Dimpley+CrosssectionHalfWidthX),:)+...
            transportThfit((Dimpley-CrosssectionHalfWidthX):(Dimpley+CrosssectionHalfWidthX),:),1);
        % dimplecrosssectionXTh=sum(dimpleThfit((Dimpley-CrosssectionHalfWidthX):(Dimpley+CrosssectionHalfWidthX),:),1);
        % reservoircrosssectionXTh=sum(reservoirThfit((Dimpley-CrosssectionHalfWidthX):(Dimpley+CrosssectionHalfWidthX),:),1);
        % crossovercrosssectionXTh=sum(crossoverThfit((Dimpley-CrosssectionHalfWidthX):(Dimpley+CrosssectionHalfWidthX),:),1);
        % transportcrosssectionXTh=sum(transportThfit((Dimpley-CrosssectionHalfWidthX):(Dimpley+CrosssectionHalfWidthX),:),1);

        datacrosssectionY =sum(meanImData(:,(Dimplex-CrosssectionHalfWidthY):(Dimplex+CrosssectionHalfWidthY)),2);
        thermalcrosssectionYThPlusBEC=sum(dimplefit(:,(Dimplex-CrosssectionHalfWidthY):(Dimplex+CrosssectionHalfWidthY))+...
            reservoirfit(:,(Dimplex-CrosssectionHalfWidthY):(Dimplex+CrosssectionHalfWidthY))+...
            crossoverfit(:,(Dimplex-CrosssectionHalfWidthY):(Dimplex+CrosssectionHalfWidthY))+...
            transportfit(:,(Dimplex-CrosssectionHalfWidthY):(Dimplex+CrosssectionHalfWidthY)),2);
        % dimplecrosssectionYThPlusBEC=sum(dimplefit((Dimplex-CrosssectionHalfWidthY):(Dimplex+CrosssectionHalfWidthY)),2);
        % reservoircrosssectionYThPlusBEC=sum(reservoirfit(:,(Dimplex-CrosssectionHalfWidthY):(Dimplex+CrosssectionHalfWidthY)),2);
        % crossovercrosssectionYThPlusBEC=sum(crossoverfit(:,(Dimplex-CrosssectionHalfWidthY):(Dimplex+CrosssectionHalfWidthY)),2);
        % transportcrosssectionYThPlusBEC=sum(transportfit(:,(Dimplex-CrosssectionHalfWidthY):(Dimplex+CrosssectionHalfWidthY)),2);
        BECcrosssectionYThPlusBEC=sum(BECfit(:,(Dimplex-CrosssectionHalfWidthY):(Dimplex+CrosssectionHalfWidthY)),2);
        thermalcrosssectionYTh=sum(dimpleThfit(:,(Dimplex-CrosssectionHalfWidthY):(Dimplex+CrosssectionHalfWidthY))+...
            reservoirThfit(:,(Dimplex-CrosssectionHalfWidthY):(Dimplex+CrosssectionHalfWidthY))+...
            crossoverThfit(:,(Dimplex-CrosssectionHalfWidthY):(Dimplex+CrosssectionHalfWidthY))+...
            transportThfit(:,(Dimplex-CrosssectionHalfWidthY):(Dimplex+CrosssectionHalfWidthY)),2);
        % dimplecrosssectionYTh=sum(dimpleThfit(:,(Dimplex-CrosssectionHalfWidthY):(Dimplex+CrosssectionHalfWidthY)),2);
        % reservoircrosssectionYTh=sum(reservoirThfit(:,(Dimplex-CrosssectionHalfWidthY):(Dimplex+CrosssectionHalfWidthY)),2);
        % crossovercrosssectionYTh=sum(crossoverThfit(:,(Dimplex-CrosssectionHalfWidthY):(Dimplex+CrosssectionHalfWidthY)),2);
        % transportcrosssectionYTh=sum(transportThfit(:,(Dimplex-CrosssectionHalfWidthY):(Dimplex+CrosssectionHalfWidthY)),2);


        dataprojectionX=sum(meanImData,1);
        thermalprojectionXThPlusBEC=sum(dimplefit+reservoirfit+crossoverfit+transportfit,1);
        % dimpleprojectionXThPlusBEC=sum(dimplefit,1);
        % reservoirprojectionXThPlusBEC=sum(reservoirfit,1);
        % crossoverprojectionXThPlusBEC=sum(crossoverfit,1);
        % transportprojectionXThPlusBEC=sum(transportfit,1);
        BECprojectionXThPlusBEC=sum(BECfit,1);
        thermalprojectionXTh=sum(dimpleThfit+reservoirThfit+crossoverThfit+transportThfit,1);
        % dimpleprojectionXTh=sum(dimpleThfit,1);
        % reservoirprojectionXTh=sum(reservoirThfit,1);
        % crossoverprojectionXTh=sum(crossoverThfit,1);
        % transportprojectionXTh=sum(transportThfit,1);

        dataprojectionY=sum(meanImData,2);
        thermalprojectionYThPlusBEC=sum(dimplefit+reservoirfit+crossoverfit+transportfit,2);
        % dimpleprojectionYThPlusBEC=sum(dimplefit,2);
        % reservoirprojectionYThPlusBEC=sum(reservoirfit,2);
        % crossoverprojectionYThPlusBEC=sum(crossoverfit,2);
        % transportprojectionYThPlusBEC=sum(transportfit,2);
        BECprojectionYThPlusBEC=sum(BECfit,2);
        thermalprojectionYTh=sum(dimpleThfit+reservoirThfit+crossoverThfit+transportThfit,2);
        % dimpleprojectionYTh=sum(dimpleThfit,2);
        % reservoirprojectionYTh=sum(reservoirThfit,2);
        % crossoverprojectionYTh=sum(crossoverThfit,2);
        % transportprojectionYTh=sum(transportThfit,2);


        % Plot cross-sections V2

        rangex=350:600;
        rangey=1:length(Y);

        X2=X(rangex);
        Y2=Y(rangey);
        meanImData2=meanImData(rangey,rangex);
        Dimpley2=Dimpley-rangey(1)+1;
        Dimplex2=Dimplex-rangex(1)+1;
        datacrosssectionX2=datacrosssectionX(rangex);
        thermalcrosssectionXTh2=thermalcrosssectionXTh(rangex);
        BECcrosssectionXThPlusBEC2=BECcrosssectionXThPlusBEC(rangex);
        thermalcrosssectionXThPlusBEC2=thermalcrosssectionXThPlusBEC(rangex);
        datacrosssectionY2=datacrosssectionY(rangey);
        thermalcrosssectionYTh2=thermalcrosssectionYTh(rangey);
        BECcrosssectionYThPlusBEC2=BECcrosssectionYThPlusBEC(rangey);
        thermalcrosssectionYThPlusBEC2=thermalcrosssectionYThPlusBEC(rangey);

        FIGSIZEX1=770;
        FIGSIZEY1=650;
        FIGXOFFSET1=30;
        FIGYOFFSET1=50;
        % FIGSIZEX2=500;
        % FIGSIZEY2=500;
        % FIGXOFFSET2=30;
        % FIGYOFFSET2=50;

        figure(fitsummaryfig5);
        clf;
        set(fitsummaryfig5,'position',[FIGXOFFSET1 FIGYOFFSET1 FIGSIZEX1 FIGSIZEY1]);

        axes('position', [0.1 0.35 0.65 0.55]);
        imagesc(X2,Y2,meanImData2);
        colormap(datamap);
        hold on
        s2=line(X2,repmat(Y2(Dimpley2),size(X2)),meanImData2(Dimpley2,:)+max(max(meanImData2))*0.02);
        s2.Color='k';
        s2.LineWidth=2;
        s2.LineStyle='--';
        s3=line(repmat(X2(Dimplex2),size(Y2)),Y2,meanImData2(:,Dimplex2)+max(max(meanImData2))*0.02);
        s3.Color='k';
        s3.LineWidth=2;
        s3.LineStyle='--';
        hold off

        axes('position', [0.1 0.1 0.65 0.25]);
        plot(X2,datacrosssectionX2,'k.',X2,thermalcrosssectionXTh2,'g--',X2,thermalcrosssectionXThPlusBEC2,'r',X2,BECcrosssectionXThPlusBEC2+thermalcrosssectionXThPlusBEC2,'b','LineWidth',2,'MarkerSize',12);
        % axis([X2(1) X2(end) min(thermalcrosssectionXTh2) max(BECcrosssectionXThPlusBEC2+thermalcrosssectionXThPlusBEC2)*1.05]);
        axis tight
        set(gca,'YTickLabelMode','manual','YTickLabel',[]);

        axes('position', [0.75 0.35 0.15 0.55]);
        plot(datacrosssectionY2,Y2,'k.',thermalcrosssectionYTh2,Y2,'g--',thermalcrosssectionYThPlusBEC2,Y2,'r',BECcrosssectionYThPlusBEC2+thermalcrosssectionYThPlusBEC2,Y2,'b','LineWidth',2,'MarkerSize',12);
        set(gca,'YDir','reverse','XTickLabelMode','manual','YTickLabelMode','manual','XTickLabel',[]);
        axis tight



        figure(fitsummaryfig7);
        clf;
        set(fitsummaryfig7,'position',[FIGXOFFSET1 FIGYOFFSET1 FIGSIZEX1 FIGSIZEY1]);

        axes('position', [0.1 0.35 0.65 0.55]);
        imagesc(X2,Y2,meanImData2);
        colormap(datamap);
        hold on
        s2=line(X2,repmat(Y2(Dimpley2),size(X2)),meanImData2(Dimpley2,:)+max(max(meanImData2))*0.02);
        s2.Color='k';
        s2.LineWidth=2;
        s2.LineStyle='--';
        s3=line(repmat(X2(Dimplex2),size(Y2)),Y2,meanImData2(:,Dimplex2)+max(max(meanImData2))*0.02);
        s3.Color='k';
        s3.LineWidth=2;
        s3.LineStyle='--';
        hold off

        axes('position', [0.1 0.1 0.65 0.25]);
        plot(X2,datacrosssectionX2,'k.',X2,thermalcrosssectionXTh2,'r','LineWidth',2,'MarkerSize',12);
        % axis([X2(1) X2(end) min(thermalcrosssectionXTh2) max(BECcrosssectionXThPlusBEC2+thermalcrosssectionXThPlusBEC2)*1.05]);
        axis tight
        set(gca,'YTickLabelMode','manual','YTickLabel',[]);

        axes('position', [0.75 0.35 0.15 0.55]);
        plot(datacrosssectionY2,Y2,'k.',thermalcrosssectionYTh2,Y2,'r','LineWidth',2,'MarkerSize',12);
        set(gca,'YDir','reverse','XTickLabelMode','manual','YTickLabelMode','manual','XTickLabel',[]);
        axis tight



        % figure(fitsummaryfig5);
        % set(gcf,'Position',[680   168   880   810]);
        % subplot(2,2,1,'replace');
        % %subplot('position',[0.1 0.7 PCAcrop(4)/(PCAcrop(4)+PCAcrop(3))/1.5 PCAcrop(3)/(PCAcrop(4)+PCAcrop(3))/1.5]);
        % imagesc(X,Y,meanImData);
        % set(gca,'YDir','normal');
        % colormap(datamap);
        % subplot(2,2,2,'replace');
        % %subplot('position',[0.8 0.7 PCAcrop(4)/(PCAcrop(4)+PCAcrop(3))/8 PCAcrop(3)/(PCAcrop(4)+PCAcrop(3))/1.5]);
        % plot(datacrosssectionY,Y,'k.',thermalcrosssectionYTh,Y,'g',BECcrosssectionYThPlusBEC+thermalcrosssectionYThPlusBEC,Y,'b',thermalcrosssectionYThPlusBEC,Y,'r');
        % axis([min(thermalcrosssectionYTh) max(BECcrosssectionYThPlusBEC+thermalcrosssectionYThPlusBEC)*1.05 Y(1) Y(end)]);
        % ylabel('Position after 18ms TOF [mm]');
        % xlabel('Atoms cross-section');
        % title('Cross-section');
        % legend('Data','Thermal only fit','Thermal+BEC fit','Thermal+BEC fit minus BEC')
        % subplot(2,2,3,'replace');
        % %subplot('position',[0.1 0.3 PCAcrop(4)/(PCAcrop(4)+PCAcrop(3))/1.5 PCAcrop(3)/(PCAcrop(4)+PCAcrop(3))/1.5]);
        % plot(X,datacrosssectionX,'k.',X,thermalcrosssectionXTh,'g',X,BECcrosssectionXThPlusBEC+thermalcrosssectionXThPlusBEC,'b',X,thermalcrosssectionXThPlusBEC,'r');
        % axis([X(1) X(end) min(thermalcrosssectionXTh) max(BECcrosssectionXThPlusBEC+thermalcrosssectionXThPlusBEC)*1.05]);
        % ylabel('Atoms cross-section');
        % xlabel('Position after 18ms TOF [mm]');
        % title('Cross-section');
        % legend('Data','Thermal only fit','Thermal+BEC fit','Thermal+BEC fit minus BEC')


        figure(fitsummaryfig6);
        % subplot(2,2,4,'replace');
        blursize=3;
        [blurmeanImData]=blurdata(meanImData,blursize);
        Xb=X((blursize+1):(end-blursize));
        Yb=Y((blursize+1):(end-blursize));
        rangex=[325:650];
        rangey=1:length(Yb);
        s=surf(Xb(rangex),Yb(rangey),blurmeanImData(rangey,rangex));
        set(gca,'YDir','normal');
        colormap(datamap);
        s.EdgeColor = 'none';
        % s.AmbientStrength=0;
        % s.DiffuseStrength=0.1;
        % s.SpecularStrength=0.9;
        % s.SpecularExponent=10;
        set(gca,'Color','k')
        shading interp
        lightangle(175,50)
        lightangle(175,60)
        lightangle(175,70)
        s.FaceLighting = 'gouraud';
        % s.AmbientStrength = 0.2;
        % s.DiffuseStrength = 0.6;
        % s.SpecularStrength = 0.9;
        s.AmbientStrength = 0.3;
        s.DiffuseStrength = 0.4;
        s.SpecularStrength = 0.2;
        s.SpecularExponent = 25;
        s.BackFaceLighting = 'unlit';
        axis tight
        % view([8.5000   58.0000]);
        view([3.5000   50.0000]);

        hold on;

        s2=line(Xb(rangex),repmat(Y(Dimpley),size(rangex)),blurmeanImData(Dimpley-blursize,rangex)+max(max(blurmeanImData))*0.02);
        s2.Color='k';

        s3=line(repmat(X(Dimplex),size(rangey)),Yb(rangey),blurmeanImData(rangey,Dimplex-blursize)+max(max(blurmeanImData))*0.02);
        s3.Color='k';

        hold off;



        % figure(fitsummaryfig4);
        % subplot(2,2,1,'replace');
        % imagesc(X,Y,meanImData);
        % set(gca,'YDir','normal');
        % colormap(datamap);
        % subplot(2,2,2,'replace');
        % plot(dataprojectionY,Y,'k.',thermalprojectionYTh,Y,'g',thermalprojectionYThPlusBEC+BECprojectionYThPlusBEC,Y,'b',thermalprojectionYThPlusBEC,Y,'r');
        % axis([min(thermalprojectionYTh) max(BECprojectionYThPlusBEC+thermalprojectionYThPlusBEC)*1.05 Y(1) Y(end)]);
        % ylabel('Position after 18ms TOF [mm]');
        % xlabel('Atoms projection');
        % title('Projection');
        % legend('Data','Thermal only fit','Thermal+BEC fit','Thermal+BEC fit minus BEC')
        % subplot(2,2,3,'replace');
        % plot(X,dataprojectionX,'k.',X,thermalprojectionXTh,'g',X,thermalprojectionXThPlusBEC+BECprojectionXThPlusBEC,'b',X,thermalprojectionXThPlusBEC,'r');
        % axis([X(1) X(end) min(thermalprojectionXTh) max(BECprojectionXThPlusBEC+thermalprojectionXThPlusBEC)*1.05]);
        % ylabel('Atoms projection');
        % xlabel('Position after 18ms TOF [mm]');
        % title('Projection');
        % legend('Data','Thermal only fit','Thermal+BEC fit','Thermal+BEC fit minus BEC')
        % 





        % save pdf pictures

        % saveas(fitsummaryfig1,[directory,'PaperFitsMean.pdf']);
        % saveas(fitsummaryfig2,[directory,'PaperResidualsMean.pdf']);
        % saveas(fitsummaryfig3,[directory,'PaperCrosssectionMean.pdf']);
        % saveas(fitsummaryfig4,[directory,'PaperProjectionMean.pdf']);
        % saveas(fitsummaryfig5,[directory,'PaperCrosssectionV2.pdf']);

        saveas(fitsummaryfig1,[directory,header1,'FitsMean',header2,'.png']);
        saveas(fitsummaryfig2,[directory,header1,'ResidualsMean',header2,'.png']);
        saveas(fitsummaryfig3,[directory,header1,'CrosssectionMean',header2,'.png']);
        saveas(fitsummaryfig4,[directory,header1,'ProjectionMean',header2,'.png']);
        saveas(fitsummaryfig5,[directory,header1,'CrosssectionV2',header2,'.png']);
        saveas(fitsummaryfig6,[directory,header1,'3Ddata',header2,'.png']);
        saveas(fitsummaryfig7,[directory,header1,'CrosssectionV2-Thermal',header2,'.png']);



        %imwrite((meanImData-fittedThData+10)/128*255,residualmap,[directory,'ResidualsTest.bmp'],'bmp');

    end
end
