function varargout=constructSSBEC6(Parameters,xx,yy)
% function [estimatedprofile,dimplefit,reservoirfit,crossoverfit,transportfit,BECfit]=constructSSBEC4(Parameters,xx,yy)

% Parameters(1) =DimpleN;
% Parameters(2) =DimpleWy;
% Parameters(3) =ReservoirN;
% Parameters(4) =ReservoirWy;
% Parameters(5) =ReservoirWx;
% Parameters(6) =CrossoverN;
% Parameters(7) =CrossoverWy;
% Parameters(8) =CrossoverWx;
% Parameters(9) =Dimplex;
% Parameters(10)=Dimpley;
% Parameters(11)=Crossoverx;
% Parameters(12)=Reservoirx;
% Parameters(13)=transportN;
% Parameters(14)=transportX;
% Parameters(15)=transportWx;
% Parameters(16)=transportY;
% Parameters(17)=transportWy;
% Parameters(18)=Background;
% Parameters(19)=BECN;
% Parameters(20)=BECwx;
% Parameters(21)=BECwy;
% Parameters(22)=BECX;
% Parameters(23)=BECY;

global mSr aScat tof
global hbarOverAu 


%% construct dimple profile
DimpleN=abs(Parameters(1));     % Parameters(1) =DimpleN;
Dimplex=Parameters(9);          % Parameters(9) =Dimplex;
Dimpley=Parameters(10);         % Parameters(10)=Dimpley;
DimpleWy=Parameters(2);         % Parameters(2) =DimpleWy;

dimplefit=exp(-((yy-Dimpley)/DimpleWy).^2-((xx-Dimplex)/DimpleWy).^2);
dimplefit=DimpleN*dimplefit;

%% construct reservoir profile
N=abs(Parameters(3));   % Parameters(3) =ReservoirN;
x0=Parameters(12);      % Parameters(12)=Reservoirx;
y0=Parameters(10);      % Parameters(10)=Dimpley;
Wy=Parameters(4);       % Parameters(4) =ReservoirWy;
Wx=Parameters(5);       % Parameters(5) =ReservoirWx;

reservoirfit=exp(-((yy-y0)/Wy).^2-((xx-x0)/Wx).^2);
reservoirfit=N*reservoirfit;

%% construct crossover profile
CrossoverN=abs(Parameters(6));  % Parameters(6) =CrossoverN;
Crossoverx=Parameters(11);      % Parameters(11)=Crossoverx;
Dimpley=Parameters(10);         % Parameters(10)=Dimpley;
CrossoverWy=Parameters(7);      % Parameters(7) =CrossoverWy;
CrossoverWx=Parameters(8);      % Parameters(8) =CrossoverWx;

crossoverfit=exp(-((yy-Dimpley)/CrossoverWy).^2-((xx-Crossoverx)/CrossoverWx).^2);
crossoverfit=CrossoverN*crossoverfit;

%% construct transport guide profile
transportN=Parameters(13);      % Parameters(13)=transportN;
transportX=Parameters(14);      % Parameters(14)=transportX;
transportWx=Parameters(15);     % Parameters(15)=transportWx;
transportY=Parameters(16);      % Parameters(16)=transportY;
transportWy=Parameters(17);     % Parameters(17)=transportWy;
Background=Parameters(18);      % Parameters(18)=Background;

transportfit=transportN./( 1+exp((xx-transportX)/transportWx) ).*...
    exp(-((yy-transportY)/transportWy).^2)+Background;

%% construct BEC profile
BECN=Parameters(19);        % Parameters(19)=BECN;
if BECN>0
    BECwx=Parameters(20);   % Parameters(20)=BECwx; => trapping frequency omega
    BECwy=Parameters(21);   % Parameters(21)=BECwy; => trapping frequency omega
    BECX=Parameters(22);    % Parameters(22)=BECX;
    BECY=Parameters(23);    % Parameters(23)=BECY;
    
    
    % First evaluations were from Pethick, Smith - Bose-Einstein Condensation in Dilute Gases
    % Expansion of a BEC from an isotropic trap (pg 195)    
    % Also looked at https://arxiv.org/pdf/cond-mat/9904034.pdf pg 32 but did not use
    % Now use castin dum 1996 paper theory (numerical evaluation of the proper parametrization)
    
    
    % Parameters obtained from castin-dum theory, with trap frequencies 330/740/315 Hz in X/Y/Z @DT (-9.7, -3.9, -12)
    R0Fact = 0.769894;
    expoFact = 0.643673;
    % Parameters obtained from castin-dum theory, with trap frequencies 345/775/330 Hz in X/Y/Z @DT (-9.1, -4.0, -11.5)
    %R0Fact = 0.769216;
    %expoFact = 0.645115;
    
    
    omegaHO = (BECwx*BECwx*BECwy)^(1/3);
    aHO=(hbarOverAu/(mSr*omegaHO))^0.5;
    R0=(15*BECN*aScat/aHO)^(1/5)*aHO;
    %R_0=R_0*(2/pi)^(1/10)*(15)^(1/5);

    
    %R_0x=(15*BECN*aScat/aHO)^(1/5)*aHO*(omegaHO/BECwx);
    %Rx=R_0x*(2/3*omegaHO^2*tof^2)^0.5 * (omegaHO/BECwx)^(-5/2)  *1e3; % units in mm => old faulty version
    Rx= R0 * R0Fact *(omegaHO*tof) * (BECwx/omegaHO)^(expoFact)  *1e3; % units in mm
    %R_0y=(15*BECN*aScat/aHO)^(1/5)*aHO*(omegaHO/BECwy);
    %Ry=R_0y*(2/3*omegaHO^2*tof^2)^0.5 * (omegaHO/BECwy)^(-5/2)  *1e3; % units in mm => old faulty version
    Ry= R0 * R0Fact *(omegaHO*tof) * (BECwy/omegaHO)^(expoFact)  *1e3; % units in mm
    
    
    %Rx = BECwx/25/1e3; %test
    %Ry = BECwy/25/1e3; %test
    
    
    %BECfit=max(0,1-(((yy-BECY)/Ry).^2+((xx-BECX)/Rx).^2));
    %BECfit=max(0,1-(((yy-BECY)/Ry).^2+((xx-BECX)/Rx).^2).^(3/2)); %the power of 3/2 is due to the integration of the profile over 1 axis (2D picture) => old faulty version
    BECfit=max(0,real((1-((yy-BECY)/Ry).^2-((xx-BECX)/Rx).^2).^(3/2))); %the power of 3/2 is due to the integration of the profile over 1 axis (2D picture)
    BECfit=BECfit*BECN/sum(sum(BECfit));
else
    BECfit=zeros(size(transportfit));
end


%% Sum up all profiles and give function's outputs
estimatedprofile=dimplefit+reservoirfit+crossoverfit+transportfit+BECfit;

if nargout>=1
    varargout{1}=estimatedprofile;
end
if nargout>=2
    varargout{2}=dimplefit;
end
if nargout>=3
    varargout{3}=reservoirfit;
end
if nargout>=4
    varargout{4}=crossoverfit;
end
if nargout>=5
    varargout{5}=transportfit;
end
if nargout>=6
    varargout{6}=BECfit;
end


end