
global cLum h hbar kB au a0
global mSr a8484 aScat lambda gamma clebsch detuning absCross tof
global hbarOverAu auOverkB

%% Definition of useful constants and physical quantities

cLum=2.99792458e8; % m/s ; exactly defined
h=6.62607015e-34; % J.s ; exactly defined
hbar = h/(2*pi);
kB = 1.380649e-23; %J/K ; exactly defined
au = 1.66053906660e-27; % kg
a0 = 0.0529177210903e-9; % Bohr radius, in m
hbarOverAu = hbar/au;
auOverkB = au / kB;


m84Sr =  83.913425; % au
m86Sr =  85.9092607309; % au
m87Sr =  86.9088774970; % au
m88Sr =  87.9056122571; % au
mSr = m84Sr; % au
% a8686 = 823 * a0;
a8484 = 122.7*a0; % m
aScat = a8484; % m
lambda=460.862369e-9; % m
gamma=2*pi*30.2e6; % s^-1
detuning=2*pi * 0;
clebsch=1;
absCross=clebsch*3*lambda^2/(2*pi*(1+(detuning/(2*gamma))^2)); % m^2
tof=18e-3; % time of flight, in s


                         


%% loading of results from the fitting program

%load('Q:\qgases\groups\strontium\SrCAL\Data\SSBEC\191226\S1021\fitdataset.mat');
%load('Q:\qgases\groups\strontium\SrCAL\Data\SSBEC\191226\S1021\imagedataset.mat')



[sortedxdata,indexlist]=sort(xdatagood);
x0BECNList = x0series(indexlist+1,19);
sigma0BECNList = x0stdseries(indexlist+1,19);

expCycleTime = 30; % in s
Fs = 1/expCycleTime;
L = length(x0BECNList);
t = (0:L-1)*expCycleTime;
NFFT = 2^nextpow2(L); % Next power of 2 from length of y

fftBECNb = fft(x0BECNList,NFFT)/L;
f = Fs/2*linspace(0,1,NFFT/2+1);
figure
plot(f,2*abs(fftBECNb(1:NFFT/2+1)))
title('Single-Sided Amplitude Spectrum of NBEC(t)')
xlabel('Frequency (Hz)')
ylabel('|fft(NBEC)(f)|')

fftBECNbNoise = fft(sigma0BECNList,NFFT)/L;
figure
plot(f,2*abs(fftBECNbNoise(1:NFFT/2+1)))
title('Single-Sided Amplitude Spectrum of sigmaBEC(t)')
xlabel('Frequency (Hz)')
ylabel('|fft(sigmaBEC)(f)|')


% 
% %coherence time
[intensityAutoCorr,lag] = xcorr(x0BECNList);  % / by g(0)
intensityAutoCorr0 = intensityAutoCorr(length(x0BECNList));
[m,i] = max(intensityAutoCorr);
intensityAutoCorr=intensityAutoCorr/intensityAutoCorr0;

%intensityAutoCorr = intensityAutoCorr(lag>0);
%lag = lag(lag>0);

figure
plot((lag/Fs),intensityAutoCorr)
%semilogy((lag/Fs),intensityAutoCorr)

%% Prepare the data for analysis

sizMat = size(PCAmatrix);
nbTotPic = sizMat(1)-1;
meanImDataTab = repmat(PCAmatrix(1,:),nbTotPic,1);


PCAcrop = roilocation;
X=((1:size(imdata,2))+PCAcrop(2)-1)*SSBECfitparam.Xcal;
Y=((1:size(imdata,1))+PCAcrop(1)-1)*SSBECfitparam.Ycal;
[xx,yy]=meshgrid(X,Y);
[dimX,dimY] = size(xx);


%% calculate the chi square

stdDataTab  = sqrt( sum( ( meanImDataTab - PCAmatrix(2:nbTotPic+1,:) ).^2 , 1) / (nbTotPic-1) );
stdDataTab = reshape(stdDataTab,[dimX dimY]);
meanImData = reshape(meanImDataTab(1,:),[dimX dimY]);

x0ThBECseries = (1:23)*0;
x0ThBECseries(1:18) = x0InitThBECseries(1,1:18);
chiSquareTh = calculateChiSquareKnowingStd(meanImData,x0ThBECseries,stdDataTab,xx,yy);
chiSquareThPlusBEC = calculateChiSquareKnowingStd(meanImData,x0series(1,:),stdDataTab,xx,yy);
display(['Chi square th+BEC: ',num2str(chiSquareThPlusBEC),' and chi square th only: ',num2str(chiSquareTh)]);

% test calculation of chi square with dicy definition
NbPixPerBin =3;
fittedData = constructSSBEC6(x0series(1,:),xx,yy);
chiSquareThPlusBEC2 = calculateChiSquare(meanImData,fittedData,length(x0series(1,:))-2,NbPixPerBin,NbPixPerBin,true);


%% calculate the weighted mean of fit parameters and their std err

weigthTab = (x0stdseries(2:nbTotPic+1,:)).^(-2);
weightedMeanFitValues = sum(x0series(2:nbTotPic+1,:) .* weigthTab  ,1) ./ sum(weigthTab,1);
stdErrWeightedMean = sqrt(1./sum(weigthTab,1)); 

display(['Weighted mean of fit parameters                      : ',num2str(weightedMeanFitValues)]);
display(['Standard error of the weighted mean of fit parameters: ',num2str(stdErrWeightedMean)]);


%% read the weighted mean of fit parameters and their std err

x0DimpleN=weightedMeanFitValues(1);         % Parameters(1)=DimpleN;
x0DimpleWy=weightedMeanFitValues(2);        % Parameters(2)=DimpleWy;
x0ReservoirN=weightedMeanFitValues(3);      % Parameters(3)=ReservoirN;
x0ReservoirWy=weightedMeanFitValues(4);     % Parameters(4)=ReservoirWy;
x0ReservoirWx=weightedMeanFitValues(5);     % Parameters(5)=ReservoirWx;
x0CrossoverN=weightedMeanFitValues(6);      % Parameters(6)=CrossoverN;
x0CrossoverWy=weightedMeanFitValues(7);     % Parameters(7)=CrossoverWy;
x0CrossoverWx=weightedMeanFitValues(8);     % Parameters(8)=CrossoverWx;
x0Dimplex=weightedMeanFitValues(9);         % Parameters(9)=Dimplex;
x0Dimpley=weightedMeanFitValues(10);        % Parameters(10)=Dimpley;
x0Crossoverx=weightedMeanFitValues(11);     % Parameters(11)=Crossoverx;
x0Reservoirx=weightedMeanFitValues(12);     % Parameters(12)=Reservoirx;
x0TransportN=weightedMeanFitValues(13);     % Parameters(13)=TransportN;
x0Transportx=weightedMeanFitValues(14);     % Parameters(14)=Transportx;
x0TransportWx=weightedMeanFitValues(15);    % Parameters(15)=TransportWx;
x0Transporty=weightedMeanFitValues(16);     % Parameters(16)=Transporty;
x0TransportWy=weightedMeanFitValues(17);    % Parameters(17)=TransportWy;
x0Background=weightedMeanFitValues(18);     % Parameters(18)=Background;
x0BECN=weightedMeanFitValues(19);           % Parameters(19)=BECN;
x0BECwx=weightedMeanFitValues(20);          % Parameters(20)=BECwx;
x0BECwy=weightedMeanFitValues(21);          % Parameters(21)=BECwy;
x0BECX=weightedMeanFitValues(22);           % Parameters(22)=BECx;
x0BECY=weightedMeanFitValues(23);           % Parameters(23)=BECy;

sigma0DimpleN=stdErrWeightedMean(1);         % Parameters(1)=DimpleN;
sigma0DimpleWy=stdErrWeightedMean(2);        % Parameters(2)=DimpleWy;
sigma0ReservoirN=stdErrWeightedMean(3);      % Parameters(3)=ReservoirN;
sigma0ReservoirWy=stdErrWeightedMean(4);     % Parameters(4)=ReservoirWy;
sigma0ReservoirWx=stdErrWeightedMean(5);     % Parameters(5)=ReservoirWx;
sigma0CrossoverN=stdErrWeightedMean(6);      % Parameters(6)=CrossoverN;
sigma0CrossoverWy=stdErrWeightedMean(7);     % Parameters(7)=CrossoverWy;
sigma0CrossoverWx=stdErrWeightedMean(8);     % Parameters(8)=CrossoverWx;
sigma0Dimplex=stdErrWeightedMean(9);         % Parameters(9)=Dimplex;
sigma0Dimpley=stdErrWeightedMean(10);        % Parameters(10)=Dimpley;
sigma0Crossoverx=stdErrWeightedMean(11);     % Parameters(11)=Crossoverx;
sigma0Reservoirx=stdErrWeightedMean(12);     % Parameters(12)=Reservoirx;
sigma0TransportN=stdErrWeightedMean(13);     % Parameters(13)=TransportN;
sigma0Transportx=stdErrWeightedMean(14);     % Parameters(14)=Transportx;
sigma0TransportWx=stdErrWeightedMean(15);    % Parameters(15)=TransportWx;
sigma0Transporty=stdErrWeightedMean(16);     % Parameters(16)=Transporty;
sigma0TransportWy=stdErrWeightedMean(17);    % Parameters(17)=TransportWy;
sigma0Background=stdErrWeightedMean(18);     % Parameters(18)=Background;
sigma0BECN=stdErrWeightedMean(19);           % Parameters(19)=BECN;
sigma0BECwx=stdErrWeightedMean(20);          % Parameters(20)=BECwx;
sigma0BECwy=stdErrWeightedMean(21);          % Parameters(21)=BECwy;
sigma0BECX=stdErrWeightedMean(22);           % Parameters(22)=BECx;
sigma0BECY=stdErrWeightedMean(23);           % Parameters(23)=BECy;


%% calculate temperatures and atom numbers
TyDimple   = mSr * auOverkB *(x0DimpleWy   *1e-3/2^0.5/tof).^2*1E6;
TyReservoir= mSr * auOverkB *(x0ReservoirWy*1e-3/2^0.5/tof).^2*1E6;
TyCrossover= mSr * auOverkB *(x0CrossoverWy*1e-3/2^0.5/tof).^2*1E6;
TyTransport= mSr * auOverkB *(x0TransportWy*1e-3/2^0.5/tof).^2*1E6;

sigmaTyDimple   = mSr * auOverkB *(sigma0DimpleWy   *1e-3/2^0.5/tof).^2*1E6;
sigmaTyReservoir= mSr * auOverkB *(sigma0ReservoirWy*1e-3/2^0.5/tof).^2*1E6;
sigmaTyCrossover= mSr * auOverkB *(sigma0CrossoverWy*1e-3/2^0.5/tof).^2*1E6;
sigmaTyTransport= mSr * auOverkB *(sigma0TransportWy*1e-3/2^0.5/tof).^2*1E6;


NDimple   = x0DimpleN./(1/(2*pi)./(x0DimpleWy*1e-3 / 2^0.5)./(x0DimpleWy*1e-3/2^0.5))/(SSBECfitparam.Xcal*SSBECfitparam.Ycal*1e-6);
NReservoir= x0ReservoirN./(1/(2*pi)./(x0ReservoirWy*1e-3 / 2^0.5)./(x0ReservoirWx*1e-3/2^0.5))/(SSBECfitparam.Xcal*SSBECfitparam.Ycal*1e-6);
NCrossover= x0CrossoverN./(1/(2*pi)./(x0CrossoverWy*1e-3 / 2^0.5)./(x0CrossoverWx*1e-3/2^0.5))/(SSBECfitparam.Xcal*SSBECfitparam.Ycal*1e-6);

x0DimpleWySquared = x0DimpleWy^2;
sigma0DimpleWySquared = x0DimpleWySquared * 2 * sigma0DimpleWy / x0DimpleWy;
sigmaNDimple   = NDimple * sqrt( (sigma0DimpleN / x0DimpleN)^2  + (sigma0DimpleWySquared / x0DimpleWySquared)^2);
sigmaNReservoir= NReservoir * sqrt( ( sigma0ReservoirN / x0ReservoirN )^2 + ( sigma0ReservoirWy / x0ReservoirWy )^2 + ( sigma0ReservoirWx / x0ReservoirWx )^2);
sigmaNCrossover= NCrossover * sqrt( ( sigma0CrossoverN / x0CrossoverN )^2 + ( sigma0CrossoverWy / x0CrossoverWy )^2 + ( sigma0CrossoverWx / x0CrossoverWx )^2 );


display(['TempY dimple: ',num2str(TyDimple),'(',num2str(sigmaTyDimple),') muK ; TempY reservoir: ',num2str(TyReservoir),'(',num2str(sigmaTyReservoir),') muK ; TempY crossover: ',num2str(TyCrossover),'(',num2str(sigmaTyCrossover),') muK ; TempY transport: ',num2str(TyTransport),'(',num2str(sigmaTyTransport),') muK ']);
display(['Nb atom dimple: ',num2str(NDimple),'(',num2str(sigmaNDimple),') ; Nb atom reservoir: ',num2str(NReservoir),'(',num2str(sigmaNReservoir),') ; Nb atom crossover: ',num2str(NCrossover),'(',num2str(sigmaNCrossover),') ; Nb atom BEC: ',num2str(x0BECN),'(',num2str(sigma0BECN),')']);

%% save results










